# Contributing to bootstrap-scss-plugins

Whether you want to add a new plugin or simply report a bug or issue, please have a quick read through these guidelines before contributing.

## Developed with Github

We use github to host code, to track issues and feature requests, as well as accept pull requests. All other forms of communication with maintainers is not considered "official".

## [Github Flow](https://guides.github.com/introduction/flow/index.html) is the Way to Go

All code changes happen through pull requests.

Pull requests are the best way to propose changes to the codebase. We actively welcome your pull requests:

1. Fork the repo and create your branch from dev.
2. Link your pull request to any relavent open issues.
3. If you've added or changed plugins, update the documentation.
4. Make sure your code compiles. Write a test if you have to!
5. Make sure your code lints.
6. Issue the pull request!

## Any contribution you make will be under the ISC License

In short, when you submit code changes, your submissions are understood to be under the same ISC License that covers the project. Feel free to contact the maintainers if that's a concern.

## Report bugs using Github's [issues](https://github.com/coldfrontlabs/bootstrap-scss-plugins/issues)

We use GitHub issues to track public bugs. Report a bug by [opening a new issue](https://github.com/coldfrontlabs/bootstrap-scss-plugins/issues/new).

## Write bug reports with detail, background, and sample code

**Great Bug Reports** tend to have:

- A quick summary and/or background
- Steps to reproduce
  - Be specific!
  - Give sample code if you can
- What you expected would happen
- What actually happens
- Notes
  - why you think this might be happening
  - stuff you tried that didn't work

Everybody loves a thorough bug report!

## Keep Your Code Consistent

- Use the standards provided by the lint file. Run `npm run lint` to be sure.
- Keep mixins in the `mixins/` directory, utilities in the `utilities/` directory, and plugins in the root `scss/` directory.
- Try to use what is provided in "Vanilla" Bootstrap 4

## Commit Guidelines

We use an [Angular style](https://github.com/angular/angular.js/blob/master/DEVELOPERS.md#commits) for commit messages. Please make sure all commits follow this.

If you're unsure of how to format your messages, running `npm run commit` will give you a hand!

## References

This document was adapted from the open-source contribution guidelines for [Facebook's Draft](https://github.com/facebook/draft-js/blob/a9316a723f9e918afde44dea68b5f9f39b7d9b00/CONTRIBUTING.md)
